import {Endpoint} from '../base';


export class ResourcesEndpoint extends Endpoint {
    /**
     * Create a new text entity on One Hour Translation.
     *
     * On success, this endpoint responds with a unique UUID for the created 
     * resource. You may use this UUID when creating a new job request such 
     * as translation, proofreading, etc.
     *
     * @param {string} text    The content of the new text resource.
     * @retuen {Promise<any>}
     */
    async createText(text: string) : Promise<any> {
        return this.request(
            'POST', 
            '/resources/text', 
            {},  // Params.
            {}, // Headers.
            { text: text }  // Body.
        );
    }

    /**
     * Create a new file entity on One Hour Translation.
     *
     * After the resource entity is created, it can be used on job requests 
     * such as translation, proofreading, etc.
     *
     * @param {Buffer} content  File content to upload.
     * @param {string} name     Replace the file name.    
     * @param {string} mime     Replace the default mime.
     */
    async createFile(content : any, name : string, mime : string) : Promise<any> {
        try {
            return this.request(
                'POST',
                '/resources/file',
                {},  // Params.
                { 'Content-Type': 'multipart/form-data' },
                { 
                    file_name: name,
                    file_mime: mime,
                    upload: content
                }
            );
        } catch(e) {
            console.log(e);
        }

    }

    /**
     * Get the resource corresponding to the given UUID.
     *
     * @param {string} uuid  The unique identifier of the resource.
     */
    async get(uuid : string, params={}) : Promise<any> {
        return this.request(
            'GET',
            `/resources/${uuid}`,
            {},  // Query-params.
            {},  // Headers
            params  // Body.
        );
    }
}
