import {Endpoint} from '../base';


export class TranslationProjectsEndpoint extends Endpoint {
    /**
     * Create a new translation project.
     *
     * @param {string} opts.sourceLanguage   Source language code.
     * @param {string} opts.targetLanguage   Target language code.
     * @param {string[]|string} opts.sources  Array or comma-separated UUIDs.
     * @param {Number} [opts.wordcount]       Number of words to translate.
     * @param {string} [opts.notes]           Optional note for the translation.
     * @param {string} [opts.expertise]       Expertise code.
     * @param {string} [opts.callbackUrl]     
     *
     * @return {Promise<object>}
     */
    create(opts) {
        const body = {
            source_language: opts.sourceLanguage,
            target_language: opts.targetLanguage,
            sources: Array.isArray(opts.sources) 
                        ? opts.sources.join(',') 
                        : opts.sources,
            wordcount: opts.wordcount,
            notes: opts.notes,
            expertise: opts.expertise,
            callback_url: opts.callbackUrl
        };

        return this.request(
            'POST', 
            '/projects/translation',
            {}, // Query params.
            {}, // Headers.
            body
        );
    }
}
